==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/bootstrap.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array();





use Claromentis\Core;
use Claromentis\Setup;


$app = new Core\Application();
global $g_application;








$g_application = $app;
\Claromentis\Core\Services::setSharedContainer($app);


$app->register(new Core\Application\NullServiceProvider());
$app->register(new Core\Config\ConfigServiceProvider());
$app->register(new Core\Log\LogServiceProvider());
$app->register(new Core\Debug\DebugServiceProvider());
$app->register(new Core\Event\EventServiceProvider());
$app->register(new Core\Http\HttpServiceProvider());
$app->register(new Core\Http\RequestDataServiceProvider());
$app->register(new Core\Http\CanonicalUrlService());
$app->register(new Core\Application\ControllerServiceProvider());
$app->register(new Core\Psr7Bridge\Psr7BridgeServiceProvider());
$app->register(new Silex\Provider\ServiceControllerServiceProvider());
$app->register(new Core\Session\SessionServiceProvider());
$app->register(new Core\Session\SessionTimestampServiceProvider());
$app->register(new Core\DAL\DbServiceProvider());
$app->register(new Core\ORM\AnalogueServiceProvider());
$app->register(new Core\Cache\CacheServiceProvider());
$app->register(new Core\Templater\TemplaterServiceProvider());
$app->register(new Core\Twig\TwigServiceProvider());
$app->register(new Core\Localization\LocalizationServiceProvider());
$app->register(new Core\DocumentConverter\DocumentConverterServiceProvider());
$app->register(new Core\Lock\LockServiceProvider());
$app->register(new Core\Security\SecurityServiceProvider());
$app->register(new Core\CDN\CDNServiceProvider());
$app->register(new Core\HashId\HashIdServiceProvider());
$app->register(new Core\Imager\ImagerServiceProvider());
$app->register(new Core\TextUtil\TextUtilServiceProvider());
$app->register(new Core\Util\UtilServiceProvider());
$app->register(new Core\Behat\BehatServiceProvider());


$app->register(new Core\Acl\AclServiceProvider());
$app->register(new Core\Admin\PanelsServiceProvider());
$app->register(new Core\Audit\AuditServiceProvider());
$app->register(new Core\Component\ComponentServiceProvider());
$app->register(new Core\CustomCode\CustomCodeServiceProvider());
$app->register(new Core\Integration\IntegrationServiceProvider());
$app->register(new Core\Like\LikesServiceProvider());
$app->register(new Core\License\LicenseServiceProvider());
$app->register(new Core\Mail\MailServiceProvider());
$app->register(new Core\Metadata\MetadataServiceProvider());
$app->register(new Core\Notification\NotificationServiceProvider());
$app->register(new Core\Localization\PublishLocalizationProvider());
$app->register(new Core\User\UserServiceProvider());
$app->register(new Core\Variable\VariableServiceProvider());
$app->register(new Core\Widget\WidgetServiceProvider());
$app->register(new Setup\SetupServiceProvider());




$app->register(new Core\Filesystem\FilesystemServiceProvider());
$app->register(new Core\Module\ModuleServiceProvider());
return $app;

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/bootstrap.php <==
<?php
$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] ?: array()) + array();





use Claromentis\Core;
use Claromentis\Setup;


$app = new Core\Application();
global $g_application;








$g_application = $app;
\Claromentis\Core\Services::setSharedContainer($app);


$app->register(new Core\Application\NullServiceProvider());
$app->register(new Core\Config\ConfigServiceProvider());
$app->register(new Core\Log\LogServiceProvider());
$app->register(new Core\Debug\DebugServiceProvider());
$app->register(new Core\Event\EventServiceProvider());
$app->register(new Core\Http\HttpServiceProvider());
$app->register(new Core\Http\RequestDataServiceProvider());
$app->register(new Core\Http\CanonicalUrlService());
$app->register(new Core\Application\ControllerServiceProvider());
$app->register(new Core\Psr7Bridge\Psr7BridgeServiceProvider());
$app->register(new Silex\Provider\ServiceControllerServiceProvider());
$app->register(new Core\Session\SessionServiceProvider());
$app->register(new Core\Session\SessionTimestampServiceProvider());
$app->register(new Core\DAL\DbServiceProvider());
$app->register(new Core\ORM\AnalogueServiceProvider());
$app->register(new Core\Cache\CacheServiceProvider());
$app->register(new Core\Templater\TemplaterServiceProvider());
$app->register(new Core\Twig\TwigServiceProvider());
$app->register(new Core\Localization\LocalizationServiceProvider());
$app->register(new Core\DocumentConverter\DocumentConverterServiceProvider());
$app->register(new Core\Lock\LockServiceProvider());
$app->register(new Core\Security\SecurityServiceProvider());
$app->register(new Core\CDN\CDNServiceProvider());
$app->register(new Core\HashId\HashIdServiceProvider());
$app->register(new Core\Imager\ImagerServiceProvider());
$app->register(new Core\TextUtil\TextUtilServiceProvider());
$app->register(new Core\Util\UtilServiceProvider());
$app->register(new Core\Behat\BehatServiceProvider());


$app->register(new Core\Acl\AclServiceProvider());
$app->register(new Core\Admin\PanelsServiceProvider());
$app->register(new Core\Ai\AiServiceProvider());
$app->register(new Core\Audit\AuditServiceProvider());
$app->register(new Core\Component\ComponentServiceProvider());
$app->register(new Core\CustomCode\CustomCodeServiceProvider());
$app->register(new Core\Integration\IntegrationServiceProvider());
$app->register(new Core\Like\LikesServiceProvider());
$app->register(new Core\License\LicenseServiceProvider());
$app->register(new Core\Mail\MailServiceProvider());
$app->register(new Core\Metadata\MetadataServiceProvider());
$app->register(new Core\Notification\NotificationServiceProvider());
$app->register(new Core\Localization\PublishLocalizationProvider());
$app->register(new Core\User\UserServiceProvider());
$app->register(new Core\Variable\VariableServiceProvider());
$app->register(new Core\Widget\WidgetServiceProvider());
$app->register(new Setup\SetupServiceProvider());




$app->register(new Core\Filesystem\FilesystemServiceProvider());
$app->register(new Core\Module\ModuleServiceProvider());
return $app;
